<?php

namespace AsposeWords;

class AdminSettingsUI {

    public static function register() {
        $i = new AdminSettingsUI();
        add_action("admin_init", array($i, "registerAdminSettings"));
        add_action('admin_menu', array($i, "adminMenu"));

        add_filter(
                "plugin_action_links_" . plugin_basename(ASPOSE_WORDS_PLUGIN_FILE),
                array($i, "pluginActionLinks")
        );
    }

    public function adminMenu() {
        add_options_page(
                get_plugin_data(ASPOSE_WORDS_PLUGIN_FILE)["Name"] . " " . __("Settings"),
                get_plugin_data(ASPOSE_WORDS_PLUGIN_FILE)["Name"],
                "manage_options",
                dirname(plugin_basename(ASPOSE_WORDS_PLUGIN_FILE)),
                array($this, "settingsPage")
        );
    }

    public function pluginActionLinks($default_links) {
        $links = array(
            sprintf("<a href=\"%s\">%s</a>",
                    admin_url("options-general.php?page=" . dirname(plugin_basename(ASPOSE_WORDS_PLUGIN_FILE))),
                    __("Settings")
            )
        );
        return array_merge($links, $default_links);
    }

    public function registerAdminSettings() {
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_comments_text');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_post_comments');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_file_type');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_post_content_filters');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_post_date');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_post_author');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_archive_posts');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_post_categories');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_metadata');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_excerpt');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_content');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_do_shortcode');
        register_setting('aspose_doc_exporter_options', 'aspose_doc_exporter_enable_background_exports');
    }

    public function settingsPage() {
        echo Util::getTwig()->render("settings.twig", [
            "settings_fields" => (function() {
                        ob_start();
                        settings_fields('aspose_doc_exporter_options');
                        $ob = ob_get_contents();
                        ob_end_clean();
                        return $ob;
                    })(),
            "plugin_data" => get_plugin_data(ASPOSE_WORDS_PLUGIN_FILE),
            "options" => wp_load_alloptions(),
        ]);
    }

}
